This is a small package that allows you to import EU languages. 

## Usage

To get all 24 official EU languages in a list, do this:

```python 
from EULANGS import EU_LANGS

print(EU_LANGS)
``` 

## Installation

```bash 
pip install EULANGS
```